function y = MatVecC0(A,x)
%
% Pre:
%    A     m-by-n matrix.
%    x     n-by-1
%
% Post:
%    y     A*x (column-oriented method)
%
   [m,n] = size(A);
   y = zeros(m,1);
   for j=1:n
      y = y + A(:,j)*x(j);
   end;
